@@ -1,5 +1,3 @@
-/* $Id: procmap.c,v 1.14 2003/10/20 15:19:36 hadess Exp $ */
-
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -21,7 +19,13 @@
    Boston, MA 02111-1307, USA.
 */
 
+#ifdef HAVE_CONFIG_H
+#  include <config.h>
+#endif
+
 #include <locale.h>
+#include <libintl.h>
+#include <stdio.h>
 
 #include <glibtop.h>
 #include <glibtop/open.h>
@@ -59,7 +63,7 @@ main (int argc, char *argv [])
 	setlocale (LC_ALL, "");
 	bindtextdomain (GETTEXT_PACKAGE, GTOPLOCALEDIR);
 	textdomain (GETTEXT_PACKAGE);
-	
+
 	glibtop_init_r (&glibtop_global_server, 0, GLIBTOP_INIT_NO_OPEN);
 
 	glibtop_get_parameter (GLIBTOP_PARAM_METHOD, &method, sizeof (method));
@@ -81,7 +85,7 @@ main (int argc, char *argv [])
 	glibtop_init_r (&glibtop_global_server, 0, 0);
 
 	if ((argc != 2) || (sscanf (argv [1], "%d", (int *) &pid) != 1))
-		glibtop_error ("Usage: %s pid", argv [0]);
+		g_error ("Usage: %s pid", argv [0]);
 
 #ifdef GLIBTOP_INODEDB
 	inodedb = glibtop_inodedb_open (0, 0);
@@ -95,7 +99,7 @@ main (int argc, char *argv [])
 		const char *filename = NULL;
 		unsigned device, device_major, device_minor;
 		char perm [5];
-		
+
 		if (maps [i].flags & (1L << GLIBTOP_MAP_ENTRY_FILENAME))
 			filename = maps [i].filename;
 
@@ -151,8 +155,20 @@ main (int argc, char *argv [])
 				 perm);
 		}
 
+
+		g_print("smaps flags:%#llx size:%llu rss:%llu "
+			"shared_clean:%llu shared_dirty:%llu "
+			"private_clean:%llu private_dirty: %llu\n",
+			maps[i].flags,
+			maps[i].size >> 10,
+			maps[i].rss >> 10,
+			maps[i].shared_clean >> 10,
+			maps[i].shared_dirty >> 10,
+			maps[i].private_clean >> 10,
+			maps[i].private_dirty >> 10);
+
 		if (filename && (filename != maps [i].filename))
-			g_free (filename);
+			g_free ((void*)filename);
 	}
 
 	g_free (maps);
