@@ -1,5 +1,3 @@
-/* $Id: daemon.h,v 1.12 2003/10/20 15:19:44 hadess Exp $ */
-
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -25,7 +23,6 @@
 #define __GLIBTOP_DAEMON_H__
 
 #include <glibtop.h>
-#include <glibtop/error.h>
 #include <glibtop/gnuserv.h>
 
 #include <glibtop/open.h>
@@ -60,17 +57,17 @@ G_BEGIN_DECLS
 #define MSG_BUFSZ		sizeof (struct _glibtop_ipc_message)
 #define MSG_MSGSZ		(MSG_BUFSZ - sizeof (long))
 
-void handle_parent_connection (int s);
-void handle_slave_connection (int input, int output);
+void handle_parent_connection (int s) G_GNUC_INTERNAL;
+void handle_slave_connection (int input, int output) G_GNUC_INTERNAL;
 void handle_slave_command (glibtop_command *cmnd, glibtop_response *resp,
-			   const void *parameter);
+			   const void *parameter) G_GNUC_INTERNAL ;
 
 void do_output (int s, glibtop_response *resp, off_t offset,
-		size_t data_size, const void *data);
-int do_read (int s, void *ptr, size_t total_size);
+		size_t data_size, const void *data) G_GNUC_INTERNAL;
+int do_read (int s, void *ptr, size_t total_size) G_GNUC_INTERNAL;
 
-void syslog_message (int priority, char *format, ...);
-void syslog_io_message (int priority, char *format, ...);
+void syslog_message (int priority, const char *format, ...) G_GNUC_INTERNAL G_GNUC_PRINTF(2, 3);
+void syslog_io_message (int priority, const char *format, ...) G_GNUC_INTERNAL G_GNUC_PRINTF(2, 3);
 
 extern int enable_debug;
 extern int verbose_output;
