@@ -126,13 +126,28 @@ static const unsigned long _glibtop_sysdeps_fsusage =
  */
 
 #ifdef linux
-void G_GNUC_INTERNAL
+void
 _glibtop_linux_get_fsusage_read_write(glibtop *server,
 				      glibtop_fsusage *buf,
-				      const char *path);
+				      const char *path) G_GNUC_INTERNAL;
+
+static inline void
+_glibtop_get_fsusage_read_write(glibtop *server,
+				glibtop_fsusage *buf,
+				const char *path)
+{
+	_glibtop_linux_get_fsusage_read_write(server, buf, path);
+}
+
+
+#elif defined(__FreeBSD__)
+void G_GNUC_INTERNAL
+_glibtop_freebsd_get_fsusage_read_write(glibtop *server,
+					glibtop_fsusage *buf,
+					const char *path);
 
 #define _glibtop_get_fsusage_read_write(S, B, P) \
-        _glibtop_linux_get_fsusage_read_write(S, B, P)
+	_glibtop_freebsd_get_fsusage_read_write(S, B, P)
 
 #else /* default fallback */
 #warning glibtop_get_fsusage .read .write are not implemented.
@@ -143,7 +158,7 @@ _glibtop_get_fsusage_read_write(glibtop *server,
 {
   /* NOOP */
 }
-#endif
+#endif /* default fallback */
 
 /* end _glibtop_get_fsusage_read_write */
 
@@ -254,8 +269,9 @@ glibtop_get_fsusage_s (glibtop *server, glibtop_fsusage *buf,
   if (statvfs (path, &fsd) < 0)
     return;
 
-#if (defined(sun) || defined(__sun)) && (defined(__SVR4) || defined(__svr4__))
-  /* Solaris but not SunOS */
+#if (defined(sun) || defined(__sun)) && (defined(__SVR4) || defined(__svr4__)) \
+	|| defined(__FreeBSD__)
+  /* Solaris but not SunOS and FreeBSD */
   buf->block_size = fsd.f_frsize;
 #else
   /* else, including Linux */
@@ -270,7 +286,7 @@ glibtop_get_fsusage_s (glibtop *server, glibtop_fsusage *buf,
 
   buf->blocks = fsd.f_blocks;
   buf->bfree  = fsd.f_bfree;
-  buf->bavail = fsd.f_bavail;
+  buf->bavail = (fsd.f_bavail > fsd.f_bfree) ? 0 : fsd.f_bavail;
   buf->files  = fsd.f_files;
   buf->ffree  = fsd.f_ffree;
 
