@@ -1,5 +1,3 @@
-/* $Id: open.c,v 1.18 2003/10/20 15:19:49 hadess Exp $ */
-
 /* Copyright (C) 1998 Joshua Sled
    This file is part of LibGTop 1.0.
 
@@ -21,8 +19,11 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
 #include <glibtop.h>
+#include <glibtop/error.h>
 #include <glibtop/open.h>
+#include <glibtop/init_hooks.h>
 
 /* !!! THIS FUNCTION RUNS SUID ROOT - CHANGE WITH CAUTION !!! */
 
@@ -30,7 +31,7 @@ void
 glibtop_init_p (glibtop *server, const unsigned long features,
 		const unsigned flags)
 {
-	glibtop_init_func_t *init_fkt;
+	const glibtop_init_func_t *init_fkt;
 
 	if (server == NULL)
 		glibtop_error_r (NULL, "glibtop_init_p (server == NULL)");
@@ -42,7 +43,7 @@ glibtop_init_p (glibtop *server, const unsigned long features,
 
 		for (init_fkt = _glibtop_init_hook_p; *init_fkt; init_fkt++)
 			(*init_fkt) (server);
-		
+
 		server->flags |= _GLIBTOP_INIT_STATE_SYSDEPS;
 	}
 }
@@ -53,7 +54,7 @@ glibtop_open_p (glibtop *server, const char *program_name,
 		const unsigned flags)
 {
 #ifdef DEBUG
-	fprintf (stderr, "DEBUG (%d): glibtop_open_p ()\n", getpid ()); 
+	fprintf (stderr, "DEBUG (%d): glibtop_open_p ()\n", getpid ());
 #endif
 
 	/* !!! WE ARE ROOT HERE - CHANGE WITH CAUTION !!! */
@@ -63,26 +64,24 @@ glibtop_open_p (glibtop *server, const char *program_name,
 	server->machine.gid = getgid ();
 	server->machine.egid = getegid ();
 
-#ifdef __FreeBSD__
 	server->os_version_code = __FreeBSD_version;
-#endif
-  
+
 	/* Setup machine-specific data */
 	server->machine.kd = kvm_open (NULL, NULL, NULL, O_RDONLY, "kvm_open");
-	
+
 	if (server->machine.kd == NULL)
 		glibtop_error_io_r (server, "kvm_open");
-	
-	/* Drop priviledges. */	
+
+	/* Drop priviledges. */
 
 	if (setreuid (server->machine.euid, server->machine.uid))
 		_exit (1);
-	
+
 	if (setregid (server->machine.egid, server->machine.gid))
 		_exit (1);
-	
+
 	/* !!! END OF SUID ROOT PART !!! */
-		
+
 	/* Our effective uid is now those of the user invoking the server,
 	 * so we do no longer have any priviledges. */
 
