@@ -1,5 +1,3 @@
-/* $Id: uptime.c,v 1.13 2004/03/09 23:13:31 hadess Exp $ */
-
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -21,25 +19,30 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
 #include <glibtop.h>
 #include <glibtop/error.h>
 #include <glibtop/uptime.h>
 
 #include <glibtop/cpu.h>
 
-#include <glibtop_suid.h>
+#include <sys/types.h>
+#include <sys/sysctl.h>
 
 static const unsigned long _glibtop_sysdeps_uptime =
-(1L << GLIBTOP_UPTIME_UPTIME) + (1L << GLIBTOP_UPTIME_IDLETIME);
+(1L << GLIBTOP_UPTIME_UPTIME);
+
+static const unsigned long _glibtop_sysdeps_idletime =
+(1L << GLIBTOP_UPTIME_IDLETIME);
 
 static const unsigned long _required_cpu_flags =
-(1L << GLIBTOP_CPU_TOTAL) + (1L << GLIBTOP_CPU_IDLE) +
+(1L << GLIBTOP_CPU_IDLE) +
 (1L << GLIBTOP_CPU_FREQUENCY);
 
 /* Init function. */
 
 void
-glibtop_init_uptime_p (glibtop *server)
+glibtop_init_uptime_s (glibtop *server)
 {
 	server->sysdeps.uptime = _glibtop_sysdeps_uptime;
 }
@@ -47,14 +50,17 @@ glibtop_init_uptime_p (glibtop *server)
 /* Provides uptime and idle time. */
 
 void
-glibtop_get_uptime_p (glibtop *server, glibtop_uptime *buf)
+glibtop_get_uptime_s (glibtop *server, glibtop_uptime *buf)
 {
-#ifdef __NetBSD__
 	time_t now;
-	time_t uptime;
 	int mib[2];
 	struct timeval boottime;
 	size_t size;
+	glibtop_cpu cpu;
+
+	glibtop_init_s (&server, GLIBTOP_SYSDEPS_UPTIME, 0);
+
+	memset (buf, 0, sizeof (glibtop_uptime));
 
 	mib[0] = CTL_KERN;
 	mib[1] = KERN_BOOTTIME;
@@ -63,22 +69,10 @@ glibtop_get_uptime_p (glibtop *server, glibtop_uptime *buf)
 	    boottime.tv_sec != 0) {
 		time(&now);
 		buf->uptime = now - boottime.tv_sec;
-		/* XXX: don't know a useful value to put here. */
-		buf->idletime = 0;
 		buf->flags = _glibtop_sysdeps_uptime;
 	}
-#else
-	buf->flags = _glibtop_sysdeps_uptime;
 
-	glibtop_cpu cpu;
-
-	glibtop_init_p (server, (1L << GLIBTOP_SYSDEPS_UPTIME), 0);
-	
-	memset (buf, 0, sizeof (glibtop_uptime));
-
-	/* We simply calculate it from the CPU usage. */
-
-	glibtop_get_cpu_p (server, &cpu);
+	glibtop_get_cpu_s (server, &cpu);
 
 	/* Make sure all required fields are present. */
 
@@ -87,9 +81,8 @@ glibtop_get_uptime_p (glibtop *server, glibtop_uptime *buf)
 
 	/* Calculate values. */
 
-	buf->uptime = (double) cpu.total / (double) cpu.frequency;
 	buf->idletime = (double) cpu.idle / (double) cpu.frequency;
+	buf->idletime /= (double) (server->ncpu + 1);
 
-	buf->flags = _glibtop_sysdeps_uptime;
-#endif
+	buf->flags |= _glibtop_sysdeps_idletime;
 }
