@@ -21,6 +21,7 @@
 #define __LINUX__GLIBTOP_PRIVATE_H__
 
 #include <glibtop.h>
+#include <glibtop/error.h>
 
 #include <glib.h>
 
@@ -40,14 +41,8 @@ next_token(const char *p)
 	return (char*) p;
 }
 
-static inline char *
-skip_token (const char *p)
-{
-	p = next_token(p);
-	while (*p && !isspace(*p)) p++;
-	p = next_token(p);
-	return (char *)p;
-}
+char *
+skip_token (const char *p) G_GNUC_INTERNAL;
 
 static inline char *
 skip_multiple_token (const char *p, size_t count)
@@ -67,8 +62,8 @@ skip_line (const char *p)
 }
 
 
-unsigned long long G_GNUC_INTERNAL
-get_scaled(const char *buffer, const char *key);
+unsigned long long
+get_scaled(const char *buffer, const char *key) G_GNUC_INTERNAL;
 
 
 /* aborts on error */
@@ -117,6 +112,40 @@ proc_stat_after_cmd (char *p)
 		*p++ = '\0';
 	return p;
 }
+
+
+unsigned long
+get_boot_time(glibtop *server) G_GNUC_INTERNAL;
+
+
+size_t
+get_page_size(void) G_GNUC_INTERNAL;
+
+
+gboolean
+check_cpu_line(glibtop *server, const char *line, unsigned n) G_GNUC_INTERNAL;
+
+
+static inline gboolean
+check_cpu_line_warn(glibtop *server, const char *line, unsigned i)
+{
+	gboolean ret;
+
+	ret = check_cpu_line(server, line, i);
+
+	if (G_UNLIKELY(!ret))
+		glibtop_warn_io_r(server,
+				  "'%s' does not start with 'cpu%u'",
+				  line, i);
+
+	return ret;
+}
+
+
+gboolean
+has_sysfs(void) G_GNUC_INTERNAL G_GNUC_CONST;
+
+
 G_END_DECLS
 
 #endif /* __LINUX__GLIBTOP_PRIVATE_H__ */
