@@ -1,5 +1,3 @@
-/* $Id: loadavg.c,v 1.24 2004/11/28 01:32:55 bdejean Exp $ */
-
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -58,9 +56,9 @@ glibtop_get_loadavg_s (glibtop *server, glibtop_loadavg *buf)
 
 	file_to_buffer(server, buffer, FILENAME);
 
-	buf->loadavg [0] = strtod (buffer, &p);
-	buf->loadavg [1] = strtod (p, &p);
-	buf->loadavg [2] = strtod (p, &p);
+	buf->loadavg [0] = g_ascii_strtod (buffer, &p);
+	buf->loadavg [1] = g_ascii_strtod (p, &p);
+	buf->loadavg [2] = g_ascii_strtod (p, &p);
 
 	buf->flags = _glibtop_sysdeps_loadavg;
 
