@@ -1,5 +1,3 @@
-/* $Id: sem_limits.c,v 1.19 2005/12/12 09:38:12 jamesh Exp $ */
-
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -71,7 +69,7 @@ glibtop_get_sem_limits_s (glibtop *server, glibtop_sem_limits *buf)
 
 	buf->flags = _glibtop_sysdeps_sem_limits;
 
-	arg.array = (ushort *) &seminfo;
+	arg.array = (void *) &seminfo;
 	semctl (0, 0, IPC_INFO, arg);
 
 	buf->semmap = seminfo.semmap;
