@@ -1,5 +1,3 @@
-/* $Id: procmap.c,v 1.7 2003/10/19 16:55:43 carlos Exp $ */
-
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -21,9 +19,9 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
 #include <glibtop.h>
 #include <glibtop/error.h>
-#include <glibtop/xmalloc.h>
 #include <glibtop/procmap.h>
 
 static const unsigned long _glibtop_sysdeps_proc_map = 0;
