@@ -1,5 +1,3 @@
-/* $Id: open.c,v 1.9 2004/06/09 18:52:22 bdejean Exp $ */
-
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -21,8 +19,10 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
 #include <glibtop.h>
 #include <glibtop/open.h>
+#include <glibtop/init_hooks.h>
 
 /* !!! THIS FUNCTION RUNS SUID ROOT - CHANGE WITH CAUTION !!! */
 
@@ -30,7 +30,7 @@ void
 glibtop_init_p (glibtop *server, const unsigned long features,
 		const unsigned flags)
 {
-	glibtop_init_func_t *init_fkt;
+	const glibtop_init_func_t *init_fkt;
 
 	if (server == NULL)
 		glibtop_error_r (NULL, "glibtop_init_p (server == NULL)");
