@@ -1,7 +1,3 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
-
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -23,6 +19,7 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
 #include <glibtop.h>
 #include <glibtop/error.h>
 #include <glibtop/shm_limits.h>
@@ -33,22 +30,18 @@ static const unsigned long _glibtop_sysdeps_shm_limits = 0;
 
 /* Init function. */
 
-int
+void
 glibtop_init_shm_limits_p (glibtop *server)
 {
-    server->sysdeps.shm_limits = _glibtop_sysdeps_shm_limits;
-
-    return 0;
+	server->sysdeps.shm_limits = _glibtop_sysdeps_shm_limits;
 }
 
 /* Provides information about sysv ipc limits. */
 
-int
+void
 glibtop_get_shm_limits_p (glibtop *server, glibtop_shm_limits *buf)
 {
-    glibtop_init_p (server, GLIBTOP_SYSDEPS_SHM_LIMITS, 0);
-	
-    memset (buf, 0, sizeof (glibtop_shm_limits));
+	glibtop_init_p (server, GLIBTOP_SYSDEPS_SHM_LIMITS, 0);
 
-    return 0;
+	memset (buf, 0, sizeof (glibtop_shm_limits));
 }
