@@ -1,7 +1,3 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
-
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -23,6 +19,7 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
 #include <glibtop.h>
 #include <glibtop/error.h>
 #include <glibtop/swap.h>
@@ -33,22 +30,18 @@ static const unsigned long _glibtop_sysdeps_swap = 0;
 
 /* Init function. */
 
-int
+void
 glibtop_init_swap_p (glibtop *server)
 {
-    server->sysdeps.swap = _glibtop_sysdeps_swap;
-
-    return 0;
+	server->sysdeps.swap = _glibtop_sysdeps_swap;
 }
 
 /* Provides information about swap usage. */
 
-int
+void
 glibtop_get_swap_p (glibtop *server, glibtop_swap *buf)
 {
-    glibtop_init_p (server, GLIBTOP_SYSDEPS_SWAP, 0);
-	
-    memset (buf, 0, sizeof (glibtop_swap));
+	glibtop_init_p (server, GLIBTOP_SYSDEPS_SWAP, 0);
 
-    return 0;
+	memset (buf, 0, sizeof (glibtop_swap));
 }
